#
# spec file for package python-ldaptor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define binaries ldaptor-fetchschema ldaptor-find-server ldaptor-getfreenumber ldaptor-ldap2dhcpconf ldaptor-ldap2dnszones ldaptor-ldap2maradns ldaptor-ldap2passwd ldaptor-ldap2pdns ldaptor-ldifdiff ldaptor-ldifpatch ldaptor-namingcontexts ldaptor-passwd ldaptor-rename ldaptor-search
%{?sle15_python_module_pythons}
Name:           python-ldaptor
Version:        21.2.0
Release:        4.4
Summary:        A Pure-Python Twisted library for LDAP
License:        MIT
URL:            https://github.com/twisted/ldaptor
Source:         https://files.pythonhosted.org/packages/source/l/ldaptor/ldaptor-%{version}.tar.gz
# PATCH-FIX-UPSTREAM remove-infinite-tmpfile-creation.patch -- gh#twisted/ldaptor#238
Patch1:         remove-infinite-tmpfile-creation.patch
# PATCH-FIX-UPSTREAM gh#twisted/ldaptor#242
Patch2:         use-configparser.patch
BuildRequires:  %{python_module Twisted-tls}
BuildRequires:  %{python_module passlib}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyparsing}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Twisted-tls
Requires:       python-passlib
Requires:       python-pyparsing
Requires:       python-zope.interface
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Ldaptor is a pure-Python library that implements:

- LDAP client logic
- separately-accessible LDAP and BER protocol message generation/parsing
- ASCII-format LDAP filter generation and parsing
- LDIF format data generation
- Samba password changing logic

%prep
%autosetup -p1 -n ldaptor-%{version}
sed -i '1 {/env python/ d}' ldaptor/ldapfilter.py
# six is not used anymore, remove from metadata
sed -i '/six/d' setup.cfg

%build
%pyproject_wheel

%install
# remove .egg for proper pip install in 15.4
rm -r ldaptor.egg-info
%pyproject_install
for b in %{binaries}; do
  %python_clone -a %{buildroot}%{_bindir}/$b
done
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand # twisted.trial: see tox config
export PYTHONPATH=%{buildroot}/%{$python_sitelib}
$python -m twisted.trial ldaptor
}

%post
%{lua:for b in rpm.expand("%{binaries}"):gmatch("%S+") do
  print(rpm.expand("%python_install_alternative " .. b .. "\n"))
end}

%postun
%{lua:for b in rpm.expand("%{binaries}"):gmatch("%S+") do
  print(rpm.expand("%python_uninstall_alternative " .. b.. "\n"))
end}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/ldaptor
%{python_sitelib}/ldaptor-%{version}.dist-info
%{lua:for b in rpm.expand("%{binaries}"):gmatch("%S+") do
  print(rpm.expand("%python_alternative %{_bindir}/" .. b.. "\n"))
end}

%changelog
* Fri Feb  9 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patchuse-configparser.patch:
  * Use non-deprecated configparser class.
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Jun 22 2022 Ben Greiner <code@bnavigator.de>
- Actually requires twisted[tls]: python-Twisted-tls
- Test suite is run by twisted.trial instead of pytest
- Add remove-infinite-tmpfile-creation.patch
  * gh#twisted/ldaptor#238
* Fri Apr 30 2021 Ben Greiner <code@bnavigator.de>
- Update to 21.2.0
  * fix ModuleNotFoundError: No module named 'cStringIO' in
    ldaptor-ldap2pdns.
  * move scripts to console_scripts entry_points
  * replace deprecated calls to base64.decodestring and base64.
    encodestring.
  * This will be the last Ldaptor release to support Python 3.5.
  * Updated the object representations of pureber and pureldap
    containers to directly pass on their contained item object
    representations. Previously they always passed on the repr
    after decoding to str with utf-8.
  * Dropped support for Python 2
  * removed Travis CI
  * The next release v20.1.0 will drop support for Python 2, and
    require Python~=3.5
  * PyPI release is now done via GitHub Action
  * the ldaptor whl is now built with pep517.
  * the ldaptor whl is tested with tox. The sdist is now untested,
    deprecated and should only be used for compatability with very
    old packaging tools.
  * the setup.py file is deprecated and will be removed in a
    future release.
  * SASL Bind without credentials caused list index out of range.
    Issue #157.
  * ldaptor.protocols.ldap.ldapserver.LDAPServer.
    handle_LDAPSearchRequest now returns an LDAPSearchResultEntry
    without any attributes when there is no match between the
    requested attributes and the entrie's attributes. Issue #166.
- Use pep517
- Fix u-a scriptlets
* Tue Feb  2 2021 Dirk Müller <dmueller@suse.com>
- filelist fix for multi-python3
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Apr 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 19.1.0
  * Basic implementation of ``ldaptor.protocols.pureldap.LDAPSearchResultReference``.
  * Explicit ``ldaptor.protocols.ldap.ldaperrors`` classes declaration was made
    to allow syntax highlighting for this module.
  * Example of using LDAP server with the database. Employees are store in the database table and retrieved
    on server initialization.
  * ``ldaptor.protocols.pureldap.LDAPPasswordModifyRequest`` string representation now contains
    ``userIdentity``, ``oldPasswd`` and ``newPasswd`` attributes. Password attributes are represented as asterisks.
  * ``ldaptor.protocols.pureldap.LDAPBindRequest`` string representation is now using asterisks to represent
    ``auth`` attribute.
  * ``NotImplementedError`` for ``ldaptor.protocols.pureldap.LDAPSearchResultReference`` was fixed.
  * StartTLS regression bug was fixed: ``ldaptor.protocols.pureldap.LDAPStartTLSRequest.oid`` and
    ``ldaptor.protocols.pureldap.LDAPStartTLSResponse.oid`` must be of bytes type.
  * replace direct dependency on pyOpenSSL with Twisted[tls]
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by matrix-synapse-ldap3
